/*
 * Copyright (C) 2016 Red Hat, Inc.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package api

import (
	"time"

	"github.com/nu7hatch/gouuid"
)

type Alert struct {
	UUID        string
	Name        string `json:",omitempty"`
	Description string `json:",omitempty"`
	Expression  string `json:",omitempty" valid:"nonzero"`
	Action      string `json:",omitempty" valid:"regexp=^(|http://|https://|file://).*$"`
	Trigger     string `json:",omitempty" valid:"regexp=^(graph|duration:.+|)$"`
	CreateTime  time.Time
}

type AlertResourceHandler struct {
}

type AlertAPIHandler struct {
	BasicAPIHandler
}

func NewAlert() *Alert {
	id, _ := uuid.NewV4()

	return &Alert{
		UUID:       id.String(),
		CreateTime: time.Now().UTC(),
	}
}

func (a *AlertResourceHandler) New() APIResource {
	id, _ := uuid.NewV4()

	return &Alert{
		UUID: id.String(),
	}
}

func (a *AlertResourceHandler) Name() string {
	return "alert"
}

func (a *Alert) ID() string {
	return a.UUID
}

func (a *Alert) SetID(i string) {
	a.UUID = i
}

func RegisterAlertAPI(apiServer *APIServer) (*AlertAPIHandler, error) {
	alertAPIHandler := &AlertAPIHandler{
		BasicAPIHandler: BasicAPIHandler{
			ResourceHandler: &AlertResourceHandler{},
			EtcdKeyAPI:      apiServer.EtcdKeyAPI,
		},
	}
	if err := apiServer.RegisterAPIHandler(alertAPIHandler); err != nil {
		return nil, err
	}
	return alertAPIHandler, nil
}
